Struct parallel_vec::param::MemoryLayout
source · [−]pub struct MemoryLayout<Param: ParallelVecParam> { /* private fields */ }Expand description
Memory layout information for creating a ParallelVec.
Users will not need to deal with this type directly, as there is no way to instantiate a copy of this struct safely.